# pydiscovergy
[![CI](https://github.com/jpbede/pydiscovergy/actions/workflows/ci.yml/badge.svg)](https://github.com/jpbede/pydiscovergy/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/jpbede/pydiscovergy/branch/dev/graph/badge.svg?token=JXB451BOSE)](https://codecov.io/gh/jpbede/pydiscovergy)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b093280986f7453391f132a46d834154)](https://www.codacy.com/gh/jpbede/pydiscovergy/dashboard)

Async Python 3 library for interacting with Discovergy smart meters API

Install
=======

`pip install pydiscovergy`